<?php
declare(strict_types=1);

namespace Drupal\views_css_grid;

use Drupal\Core\Url;

trait ViewsCssGridTraits
{
  protected function getViewsCssOptions(): array
  {
    $options = [
      'mode' => ['default' => 'auto-fill'],
      'masonry' => ['default' => false],
      'gap' => ['default' => '24px'],
      'minmax' => [
        'contains' => [
          'min' => ['default' => '300px'],
          'max' => ['default' => '1fr']
        ]
      ],
      'justify_items' => ['default' => null],
      'align_items' => ['default' => null],
      'justify_content' => ['default' => null],
      'align_content' => ['default' => null],
    ];

    return $options;
  }

  public function buildForm(&$form): void {
    $form['help'] = [
      '#type' => 'link',
      '#title' => 'CSS Grid Cheatsheet',
      '#url' => Url::fromUri('https://grid.malven.co/', [
        'attributes' => [
          'title' => $this->t("Opens a handy cheatsheet for css grid in a popup."),
          'onclick' => "window.open('https://grid.malven.co/','popup','width=960px,height=640px'); return false;",
          'target' => '_blank',
          'class' => ['button']
        ]
      ])
    ];

    $form['mode'] = [
      '#type' => 'radios',
      '#title' => $this->t('Mode'),
      '#options' => [
        'auto-fill' => 'repeat: auto-fill',
        'auto-fit' => 'repeat: auto-fit',
        'custom' => 'custom'
      ],
      '#default_value' => $this->options['mode'],
    ];

    $form['masonry'] = [
      '#type' => 'checkbox',
      '#title' => 'Masonry',
      '#description' => $this->t("Use grid-template-rows: masonry;"),
      '#default_value' => $this->options['masonry']
    ];

    $form['gap'] = [
      '#type' => 'textfield',
      '#title' => 'gap',
      '#default_value' => $this->options['gap'],
      '#attributes' => ['size' => '16']
    ];

    $form['minmax'] = [
      '#type' => 'fieldset',
      '#title' => 'minmax',
      'min' => [
        '#type' => 'textfield',
        '#title' => 'min',
        '#default_value' => $this->options['minmax']['min'],
        '#attributes' => ['size' => '16']
      ],
      'max' => [
        '#type' => 'textfield',
        '#title' => 'max',
        '#default_value' => $this->options['minmax']['max'],
        '#attributes' => ['size' => '8']
      ]
    ];

    $form['align_justify'] = [
      '#type' => 'fieldset',
      '#title' => 'Align and Justify',
    ];

    foreach (['justify_items', 'align_items', 'justify_content', 'align_content'] as $property) {
      $options = [
        null => '<default>',
        'start' => t('start'),
        'end' => t('end'),
        'center' => t('center'),
        'stretch' => t('stretch'),
      ];

      if(str_ends_with($property, 'content')) {
        $options += [
          'space-around' => t('space-around'),
          'space-between' => t('space-between'),
          'space-evenly' => t('space-evenly'),
        ];
      }

      $form['align_justify'][$property] = [
        '#type' => 'select',
        '#title' => str_replace('_', '-', $property),
        '#options' => $options,
        '#default_value' => $this->options[$property],
      ];
    }
  }
}
